# This file was auto-generated by Fern from our API Definition.

import typing

from .chat_completion_named_tool_choice_param import ChatCompletionNamedToolChoiceParam

CompletionCreateParamsNonStreamingToolChoice = typing.Union[
    typing.Literal["none"], typing.Literal["auto"], typing.Literal["required"], ChatCompletionNamedToolChoiceParam
]
