# This file was auto-generated by Fern from our API Definition.

import typing

ChatCompletionAudioParamFormat = typing.Union[typing.Literal["wav", "aac", "mp3", "flac", "opus", "pcm16"], typing.Any]
