# This file was auto-generated by Fern from our API Definition.

import typing

ManagerType = typing.Union[
    typing.Literal["round_robin", "supervisor", "dynamic", "sleeptime", "voice_sleeptime", "swarm"], typing.Any
]
