# This file was auto-generated by Fern from our API Definition.

import typing

AgentsCreateRequestInitialMessageSequenceItemRole = typing.Union[
    typing.Literal["user", "system", "assistant"], typing.Any
]
