# This file was auto-generated by Fern from our API Definition.

import typing

from ...types.json_object_response_format import JsonObjectResponseFormat
from ...types.json_schema_response_format import JsonSchemaResponseFormat
from ...types.text_response_format import TextResponseFormat

UpdateAgentResponseFormat = typing.Union[JsonObjectResponseFormat, JsonSchemaResponseFormat, TextResponseFormat]
