# This file was auto-generated by Fern from our API Definition.

import typing

from ....types.assistant_message import AssistantMessage
from ....types.letta_ping import LettaPing
from ....types.letta_stop_reason import LettaStopReason
from ....types.letta_usage_statistics import LettaUsageStatistics
from ....types.reasoning_message import ReasoningMessage
from ....types.system_message import SystemMessage
from ....types.tool_call_message import ToolCallMessage
from ....types.tool_return_message import ToolReturnMessage
from ....types.user_message import UserMessage

LettaStreamingResponse = typing.Union[
    SystemMessage,
    UserMessage,
    ReasoningMessage,
    ToolCallMessage,
    ToolReturnMessage,
    AssistantMessage,
    LettaPing,
    LettaStopReason,
    LettaUsageStatistics,
]
