# This file was auto-generated by Fern from our API Definition.

import typing

from .chat_completion_function_call_option_param import ChatCompletionFunctionCallOptionParam

CompletionCreateParamsStreamingFunctionCall = typing.Union[
    typing.Literal["none"], typing.Literal["auto"], ChatCompletionFunctionCallOptionParam
]
